using System;
using System.Web.Mvc;

namespace SimpleProgress.Framework
{
    /// <summary>
    /// Shields some common tasks for a controller that includes monitorable operations.
    /// </summary>
    public class SimpleProgressController : Controller
    {
        protected readonly ProgressManager ProgressManager;

        /// <summary>
        /// Initializes a progress manager instance.
        /// </summary>
        public SimpleProgressController()
        {
            ProgressManager = new ProgressManager();
        }

        /// <summary>
        /// Retrieves the ID of the current task (via HTTP header)
        /// </summary>
        /// <returns>Task ID</returns>
        public String GetTaskId()
        {
            // Get the header with the task ID
            var id = Request.Headers[ProgressManager.HeaderNameTaskId];
            return id ?? String.Empty;
        }

        /// <summary>
        /// Endpoint that retrieves the current status of an operation.
        /// </summary>
        /// <returns>Description</returns>
        public String Progress()
        {
            var taskId = GetTaskId(); 
            return ProgressManager.GetStatus(taskId);
        }
    }
}